#define  AUTOOPTS_INTERNAL 1
#include "autoopts/project.h"
#define  LOCAL static
#include "ao-strs.h"
#include "autoopts/options.h"
#include "autoopts/usage-txt.h"
#include "genshell.h"
#include "option-xat-attribute.h"
#include "option-value-type.h"
#include "ao-strs.h"
#include "ag-char-map.h"
#include "autoopts.h"
#include "proto.h"
#include "parse-duration.c"
#include "ao-strs.c"
#include "option-value-type.c"
#include "option-xat-attribute.c"
#include "autoopts.c"
#include "alias.c"
#include "boolean.c"
#include "check.c"
#include "configfile.c"
#include "cook.c"
#include "enum.c"
#include "env.c"
#include "file.c"
#include "find.c"
#include "genshell.c"
#include "load.c"
#include "makeshell.c"
#include "nested.c"
#include "numeric.c"
#include "pgusage.c"
#include "putshell.c"
#include "reset.c"
#include "restore.c"
#include "save.c"
#include "sort.c"
#include "stack.c"
#include "streqvcmp.c"
#include "text_mmap.c"
#include "time.c"
#include "tokenize.c"
#include "usage.c"
#include "version.c"
#include "init.c"
